==> django-versatileimagefield-0.1.4b.tar.gz: django-versatileimagefield-0.1.4b/versatileimagefield/forms.py <==
from django.forms.fields import (
    ChoiceField,
    MultiValueField,
    CharField,
    ImageField
)

from .widgets import (
    VersatileImagePPOIClickWidget,
    VersatileImagePPOISelectWidget,
    SizedImageCenterpointClickDjangoAdminWidget,
    CENTERPOINT_CHOICES
)


class VersatileImageForFormImageField(ImageField):
    """
    A django.forms.fields.ImageField subclass that provides
    proper validation when displaying fields.VersatileImageField
    as a HTML form.
    """

    def to_python(self, data):
        """
        Ensures `data` is opened so django.forms.fields.ImageField
        validation runs correctly
        """
        if data:
            data.open()
        return super(VersatileImageForFormImageField, self).to_python(data)


class SizedImageCenterpointMixIn(object):

    def compress(self, data_list):
        return tuple(data_list)


class VersatileImagePPOISelectField(SizedImageCenterpointMixIn,
                                    MultiValueField):
    widget = VersatileImagePPOISelectWidget

    def __init__(self, *args, **kwargs):
        max_length = kwargs.pop('max_length', None)
        del max_length
        fields = (
            VersatileImageForFormImageField(label='Image'),
            ChoiceField(choices=CENTERPOINT_CHOICES, label='Centerpoint')
        )
        super(VersatileImagePPOISelectField, self).__init__(
            tuple(fields), *args, **kwargs
        )


class VersatileImagePPOIClickField(SizedImageCenterpointMixIn,
                                   MultiValueField):
    widget = VersatileImagePPOIClickWidget

    def __init__(self, *args, **kwargs):
        max_length = kwargs.pop('max_length', None)
        del max_length
        fields = (
            VersatileImageForFormImageField(label='Image'),
            CharField(required=False)
        )
        super(VersatileImagePPOIClickField, self).__init__(
            tuple(fields), *args, **kwargs
        )


class SizedImageCenterpointClickDjangoAdminField(
        VersatileImagePPOIClickField):
    widget = SizedImageCenterpointClickDjangoAdminWidget
    # Need to remove `None` and `u''` so required fields will work
    # TODO: Better validation handling
    empty_values = [[], (), {}]

==> django-versatileimagefield-1.6.2.tar.gz: django-versatileimagefield-1.6.2/versatileimagefield/forms.py <==
from __future__ import unicode_literals

from django.forms.fields import (
    MultiValueField,
    CharField,
    ImageField
)

from .widgets import (
    VersatileImagePPOIClickWidget,
    SizedImageCenterpointClickDjangoAdminWidget
)


class SizedImageCenterpointMixIn(object):

    def compress(self, data_list):
        return tuple(data_list)


class VersatileImageFormField(ImageField):

    def to_python(self, data):
        """
        Ensures data is prepped properly before handing off to
        ImageField
        """
        if data is not None:
            if hasattr(data, 'open'):
                data.open()
            return super(VersatileImageFormField, self).to_python(data)


class VersatileImagePPOIClickField(SizedImageCenterpointMixIn,
                                   MultiValueField):
    widget = VersatileImagePPOIClickWidget

    def __init__(self, *args, **kwargs):
        max_length = kwargs.pop('max_length', None)
        del max_length
        fields = (
            VersatileImageFormField(label='Image'),
            CharField(required=False)
        )
        super(VersatileImagePPOIClickField, self).__init__(
            tuple(fields), *args, **kwargs
        )

    def bound_data(self, data, initial):
        to_return = data
        if data[0] is None:
            to_return = initial
        return to_return


class SizedImageCenterpointClickDjangoAdminField(
        VersatileImagePPOIClickField):
    widget = SizedImageCenterpointClickDjangoAdminWidget
    # Need to remove `None` and `u''` so required fields will work
    # TODO: Better validation handling
    empty_values = [[], (), {}]
